<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>MainWidget</name>
    <message>
        <source>rdpanel : </source>
        <translation type="obsolete">rdpanel: </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Nelze spojit</translation>
    </message>
    <message>
        <source>Station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
